summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDan McDonald <danmcd@joyent.com>2021-09-01 09:44:23 -0400
committerDan McDonald <danmcd@joyent.com>2021-09-01 09:44:23 -0400
commit575e134f07a43022f4d53ba0843876ffcfec14b7 (patch)
treeadd7b35ec37a3c5fec6113484b561cf47cdb51f9
parent81f23222e3d403fbfd30225f51836162aeaaf832 (diff)
parentc3d9bc08a709328922dddd4cf87d0341592e5f52 (diff)
downloadillumos-joyent-575e134f07a43022f4d53ba0843876ffcfec14b7.tar.gz
[illumos-gate merge]
commit c3d9bc08a709328922dddd4cf87d0341592e5f52 14040 Double punctuation in the manual commit 2cdd73db19663a333ca54a47c4bdf7abe0a4a4dd 14039 Some invalid cross-references in the manual commit a6042a7867393a536ea09edf3aa4bc76521523a4 14037 The curses manual is in section 3CURSES, not 3X commit 4a5cced59c85fb4e06290040b640fc651cceba52 13805 nwamcfg: variable may be used uninitialized commit 49e0679264dbb4a3cb279b5f200ba140798c0388 14032 viona miscounts rx bytes copied Conflicts: usr/src/man/man1m/route.1m
-rw-r--r--usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/Makefile7
-rw-r--r--usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/nwamcfg.c113
-rw-r--r--usr/src/man/man1m/acct.1m14
-rw-r--r--usr/src/man/man1m/chat.1m27
-rw-r--r--usr/src/man/man1m/format.1m21
-rw-r--r--usr/src/man/man1m/fsdb_udfs.1m18
-rw-r--r--usr/src/man/man1m/reboot.1m11
-rw-r--r--usr/src/man/man1m/route.1m6
-rw-r--r--usr/src/man/man1m/update_drv.1m18
-rw-r--r--usr/src/man/man3c/getgrouplist.3c6
-rw-r--r--usr/src/man/man3curses/forms.3curses159
-rw-r--r--usr/src/man/man3curses/menus.3curses137
-rw-r--r--usr/src/man/man3curses/panels.3curses17
-rw-r--r--usr/src/man/man3ldap/ldap_error.3ldap15
-rw-r--r--usr/src/man/man3rsm/rsm_memseg_import_set_mode.3rsm15
-rw-r--r--usr/src/man/man3sysevent/sysevents.3sysevent4
-rw-r--r--usr/src/man/man3tnf/tnfctl_indirect_open.3tnf19
-rw-r--r--usr/src/man/man7d/vioblk.7d4
-rw-r--r--usr/src/man/man7d/wscons.7d18
-rw-r--r--usr/src/man/man7i/mtio.7i12
-rw-r--r--usr/src/man/man9f/ddi_io_rep_get8.9f6
-rw-r--r--usr/src/uts/i86pc/io/viona/viona_rx.c15
22 files changed, 262 insertions, 400 deletions
diff --git a/usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/Makefile b/usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/Makefile
index 6b9572f233..ef778419b8 100644
--- a/usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/Makefile
+++ b/usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/Makefile
@@ -39,7 +39,6 @@ CLEANFILES += nwamcfg_lex.c nwamcfg_grammar.tab.c nwamcfg_grammar.tab.h
CLEANFILES += $(PROG).ln
CERRWARN += -_gcc=-Wno-switch
-CERRWARN += $(CNOWARN_UNINIT)
CERRWARN += -_gcc=-Wno-unused-variable
CERRWARN += -_gcc=-Wno-unused-label
CERRWARN += -_gcc=-Wno-implicit-function-declaration
@@ -71,10 +70,4 @@ check: $(PROG).c $(PROG).h
clean:
$(RM) $(OBJS) $(CLEANFILES)
-#
-# We don't do lint of lex- and yacc- generated source files
-#
-lint:
- $(LINT.c) -c $(PROG).c $(LDLIBS)
-
include ../../../Makefile.targ
diff --git a/usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/nwamcfg.c b/usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/nwamcfg.c
index 263f3f62b2..0c7afdf629 100644
--- a/usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/nwamcfg.c
+++ b/usr/src/cmd/cmd-inet/usr.sbin/nwamcfg/nwamcfg.c
@@ -212,22 +212,22 @@ typedef struct prop_table_entry {
/* NCU properties table */
static prop_table_entry_t ncu_prop_table[] = {
- { PT_TYPE, NWAM_NCU_PROP_TYPE },
- { PT_CLASS, NWAM_NCU_PROP_CLASS },
- { PT_PARENT, NWAM_NCU_PROP_PARENT_NCP },
+ { PT_TYPE, NWAM_NCU_PROP_TYPE },
+ { PT_CLASS, NWAM_NCU_PROP_CLASS },
+ { PT_PARENT, NWAM_NCU_PROP_PARENT_NCP },
{ PT_ACTIVATION_MODE, NWAM_NCU_PROP_ACTIVATION_MODE },
- { PT_ENABLED, NWAM_NCU_PROP_ENABLED },
- { PT_PRIORITY_GROUP, NWAM_NCU_PROP_PRIORITY_GROUP },
+ { PT_ENABLED, NWAM_NCU_PROP_ENABLED },
+ { PT_PRIORITY_GROUP, NWAM_NCU_PROP_PRIORITY_GROUP },
{ PT_PRIORITY_MODE, NWAM_NCU_PROP_PRIORITY_MODE },
- { PT_LINK_MACADDR, NWAM_NCU_PROP_LINK_MAC_ADDR },
- { PT_LINK_AUTOPUSH, NWAM_NCU_PROP_LINK_AUTOPUSH },
- { PT_LINK_MTU, NWAM_NCU_PROP_LINK_MTU },
- { PT_IP_VERSION, NWAM_NCU_PROP_IP_VERSION },
- { PT_IPV4_ADDRSRC, NWAM_NCU_PROP_IPV4_ADDRSRC },
- { PT_IPV4_ADDR, NWAM_NCU_PROP_IPV4_ADDR },
+ { PT_LINK_MACADDR, NWAM_NCU_PROP_LINK_MAC_ADDR },
+ { PT_LINK_AUTOPUSH, NWAM_NCU_PROP_LINK_AUTOPUSH },
+ { PT_LINK_MTU, NWAM_NCU_PROP_LINK_MTU },
+ { PT_IP_VERSION, NWAM_NCU_PROP_IP_VERSION },
+ { PT_IPV4_ADDRSRC, NWAM_NCU_PROP_IPV4_ADDRSRC },
+ { PT_IPV4_ADDR, NWAM_NCU_PROP_IPV4_ADDR },
{ PT_IPV4_DEFAULT_ROUTE, NWAM_NCU_PROP_IPV4_DEFAULT_ROUTE },
- { PT_IPV6_ADDRSRC, NWAM_NCU_PROP_IPV6_ADDRSRC },
- { PT_IPV6_ADDR, NWAM_NCU_PROP_IPV6_ADDR },
+ { PT_IPV6_ADDRSRC, NWAM_NCU_PROP_IPV6_ADDRSRC },
+ { PT_IPV6_ADDR, NWAM_NCU_PROP_IPV6_ADDR },
{ PT_IPV6_DEFAULT_ROUTE, NWAM_NCU_PROP_IPV6_DEFAULT_ROUTE },
{ PT_IP_PRIMARY, NWAM_NCU_PROP_IP_PRIMARY },
{ PT_IP_REQHOST, NWAM_NCU_PROP_IP_REQHOST },
@@ -236,47 +236,47 @@ static prop_table_entry_t ncu_prop_table[] = {
/* ENM properties table */
static prop_table_entry_t enm_prop_table[] = {
- { PT_ENM_FMRI, NWAM_ENM_PROP_FMRI },
- { PT_ENM_START, NWAM_ENM_PROP_START },
- { PT_ENM_STOP, NWAM_ENM_PROP_STOP },
- { PT_ACTIVATION_MODE, NWAM_ENM_PROP_ACTIVATION_MODE },
- { PT_CONDITIONS, NWAM_ENM_PROP_CONDITIONS },
- { PT_ENABLED, NWAM_ENM_PROP_ENABLED },
+ { PT_ENM_FMRI, NWAM_ENM_PROP_FMRI },
+ { PT_ENM_START, NWAM_ENM_PROP_START },
+ { PT_ENM_STOP, NWAM_ENM_PROP_STOP },
+ { PT_ACTIVATION_MODE, NWAM_ENM_PROP_ACTIVATION_MODE },
+ { PT_CONDITIONS, NWAM_ENM_PROP_CONDITIONS },
+ { PT_ENABLED, NWAM_ENM_PROP_ENABLED },
{ 0, NULL }
};
/* LOCation properties table */
static prop_table_entry_t loc_prop_table[] = {
- { PT_ACTIVATION_MODE, NWAM_LOC_PROP_ACTIVATION_MODE },
- { PT_CONDITIONS, NWAM_LOC_PROP_CONDITIONS },
- { PT_ENABLED, NWAM_LOC_PROP_ENABLED },
- { PT_LOC_NAMESERVICES, NWAM_LOC_PROP_NAMESERVICES },
+ { PT_ACTIVATION_MODE, NWAM_LOC_PROP_ACTIVATION_MODE },
+ { PT_CONDITIONS, NWAM_LOC_PROP_CONDITIONS },
+ { PT_ENABLED, NWAM_LOC_PROP_ENABLED },
+ { PT_LOC_NAMESERVICES, NWAM_LOC_PROP_NAMESERVICES },
{ PT_LOC_NAMESERVICES_CONFIG, NWAM_LOC_PROP_NAMESERVICES_CONFIG_FILE },
{ PT_LOC_DNS_CONFIGSRC, NWAM_LOC_PROP_DNS_NAMESERVICE_CONFIGSRC },
- { PT_LOC_DNS_DOMAIN, NWAM_LOC_PROP_DNS_NAMESERVICE_DOMAIN },
- { PT_LOC_DNS_SERVERS, NWAM_LOC_PROP_DNS_NAMESERVICE_SERVERS },
- { PT_LOC_DNS_SEARCH, NWAM_LOC_PROP_DNS_NAMESERVICE_SEARCH },
+ { PT_LOC_DNS_DOMAIN, NWAM_LOC_PROP_DNS_NAMESERVICE_DOMAIN },
+ { PT_LOC_DNS_SERVERS, NWAM_LOC_PROP_DNS_NAMESERVICE_SERVERS },
+ { PT_LOC_DNS_SEARCH, NWAM_LOC_PROP_DNS_NAMESERVICE_SEARCH },
{ PT_LOC_NIS_CONFIGSRC, NWAM_LOC_PROP_NIS_NAMESERVICE_CONFIGSRC },
- { PT_LOC_NIS_SERVERS, NWAM_LOC_PROP_NIS_NAMESERVICE_SERVERS },
+ { PT_LOC_NIS_SERVERS, NWAM_LOC_PROP_NIS_NAMESERVICE_SERVERS },
{ PT_LOC_LDAP_CONFIGSRC, NWAM_LOC_PROP_LDAP_NAMESERVICE_CONFIGSRC },
{ PT_LOC_LDAP_SERVERS, NWAM_LOC_PROP_LDAP_NAMESERVICE_SERVERS },
{ PT_LOC_DEFAULT_DOMAIN, NWAM_LOC_PROP_DEFAULT_DOMAIN },
- { PT_LOC_NFSV4_DOMAIN, NWAM_LOC_PROP_NFSV4_DOMAIN },
- { PT_LOC_IPF_CONFIG, NWAM_LOC_PROP_IPFILTER_CONFIG_FILE },
+ { PT_LOC_NFSV4_DOMAIN, NWAM_LOC_PROP_NFSV4_DOMAIN },
+ { PT_LOC_IPF_CONFIG, NWAM_LOC_PROP_IPFILTER_CONFIG_FILE },
{ PT_LOC_IPF_V6_CONFIG, NWAM_LOC_PROP_IPFILTER_V6_CONFIG_FILE },
- { PT_LOC_IPNAT_CONFIG, NWAM_LOC_PROP_IPNAT_CONFIG_FILE },
- { PT_LOC_IPPOOL_CONFIG, NWAM_LOC_PROP_IPPOOL_CONFIG_FILE },
- { PT_LOC_IKE_CONFIG, NWAM_LOC_PROP_IKE_CONFIG_FILE },
+ { PT_LOC_IPNAT_CONFIG, NWAM_LOC_PROP_IPNAT_CONFIG_FILE },
+ { PT_LOC_IPPOOL_CONFIG, NWAM_LOC_PROP_IPPOOL_CONFIG_FILE },
+ { PT_LOC_IKE_CONFIG, NWAM_LOC_PROP_IKE_CONFIG_FILE },
{ PT_LOC_IPSECPOL_CONFIG, NWAM_LOC_PROP_IPSECPOLICY_CONFIG_FILE },
{ 0, NULL }
};
/* Known WLAN properties table */
static prop_table_entry_t wlan_prop_table[] = {
- { PT_WLAN_BSSIDS, NWAM_KNOWN_WLAN_PROP_BSSIDS },
- { PT_WLAN_PRIORITY, NWAM_KNOWN_WLAN_PROP_PRIORITY },
- { PT_WLAN_KEYNAME, NWAM_KNOWN_WLAN_PROP_KEYNAME },
- { PT_WLAN_KEYSLOT, NWAM_KNOWN_WLAN_PROP_KEYSLOT },
+ { PT_WLAN_BSSIDS, NWAM_KNOWN_WLAN_PROP_BSSIDS },
+ { PT_WLAN_PRIORITY, NWAM_KNOWN_WLAN_PROP_PRIORITY },
+ { PT_WLAN_KEYNAME, NWAM_KNOWN_WLAN_PROP_KEYNAME },
+ { PT_WLAN_KEYSLOT, NWAM_KNOWN_WLAN_PROP_KEYSLOT },
{ PT_WLAN_SECURITY_MODE, NWAM_KNOWN_WLAN_PROP_SECURITY_MODE },
{ 0, NULL }
};
@@ -1122,7 +1122,7 @@ check_scope(int cmd)
/* Returns the active object type depending on which handle is not NULL */
static nwam_object_type_t
-active_object_type()
+active_object_type(void)
{
/* Check ncu_h before ncp_h, ncp_h must be loaded before ncu_h */
if (ncu_h != NULL)
@@ -1204,6 +1204,10 @@ do_commit()
case NWAM_OBJECT_TYPE_KNOWN_WLAN:
verr = nwam_known_wlan_validate(wlan_h, &errprop);
break;
+ default:
+ verr = NWAM_INVALID_HANDLE;
+ nwamerr(ret, "Unknown object type");
+ return;
}
if (verr != NWAM_SUCCESS)
@@ -1677,6 +1681,7 @@ destroy_func(cmd_t *cmd)
ncp_h = NULL;
} else {
nerr("Destroy error: unknown object-type");
+ ret = NWAM_INVALID_HANDLE;
}
done:
@@ -1820,6 +1825,9 @@ revert_func(cmd_t *cmd)
wlan_h = NULL;
ret = nwam_known_wlan_read(name, 0, &wlan_h);
break;
+ default:
+ ret = NWAM_INVALID_HANDLE;
+ break;
}
/* Exit this scope because handle already freed (call do_cancel()) */
@@ -1988,6 +1996,9 @@ prop_value_type(nwam_object_type_t object_type, const char *prop)
case NWAM_OBJECT_TYPE_KNOWN_WLAN:
ret = nwam_known_wlan_get_prop_type(prop, &value_type);
break;
+ default:
+ ret = NWAM_INVALID_HANDLE;
+ break;
}
if (ret != NWAM_SUCCESS)
@@ -2010,9 +2021,9 @@ str_to_nwam_value(nwam_object_type_t object_type, char *input_str, int pt_type,
int max_str_num;
nwam_value_type_t value_type;
- int64_t *int_vals;
- uint64_t *uint_vals;
- boolean_t *boolean_vals;
+ int64_t *int_vals = NULL;
+ uint64_t *uint_vals = NULL;
+ boolean_t *boolean_vals = NULL;
/*
* Worst case is that each char separated by DELIMITER, so the
@@ -2130,6 +2141,8 @@ str_to_nwam_value(nwam_object_type_t object_type, char *input_str, int pt_type,
} else if (value_type == NWAM_VALUE_TYPE_BOOLEAN) {
ret = nwam_value_create_boolean_array(boolean_vals, n, &data);
free(boolean_vals);
+ } else {
+ ret = NWAM_INVALID_HANDLE;
}
array_free((void **)val, max_str_num);
@@ -2346,6 +2359,9 @@ show_prop_test(nwam_object_type_t object_type, const char *prop,
break;
case NWAM_OBJECT_TYPE_KNOWN_WLAN:
return (B_TRUE);
+ default:
+ ret = NWAM_INVALID_HANDLE;
+ break;
}
if (ret != NWAM_SUCCESS)
continue;
@@ -2482,6 +2498,9 @@ is_prop_multivalued(nwam_object_type_t object_type, const char *prop)
case NWAM_OBJECT_TYPE_KNOWN_WLAN:
ret = nwam_known_wlan_prop_multivalued(prop, &multi);
break;
+ default:
+ ret = NWAM_INVALID_HANDLE;
+ break;
}
if (ret != NWAM_SUCCESS)
@@ -2771,11 +2790,14 @@ output_prop_val(const char *prop_name, nwam_value_t value, FILE *wf,
return;
}
tostr = bool2str;
+ } else {
+ nerr("Unknown value type");
+ return;
}
/* now, loop and print each value */
for (i = 0; i < num; i++) {
- void *val;
+ void *val = NULL;
/* get the pointer to the ith value to pass to func() */
if (value_type == NWAM_VALUE_TYPE_STRING)
@@ -3858,6 +3880,9 @@ clear_func(cmd_t *cmd)
case NWAM_OBJECT_TYPE_KNOWN_WLAN:
ret = nwam_known_wlan_delete_prop(wlan_h, prop);
break;
+ default:
+ ret = NWAM_INVALID_HANDLE;
+ break;
}
if (ret != NWAM_SUCCESS) {
@@ -4156,6 +4181,10 @@ verify_func(cmd_t *cmd)
case NWAM_OBJECT_TYPE_KNOWN_WLAN:
ret = nwam_known_wlan_validate(wlan_h, &errprop);
break;
+ default:
+ ret = NWAM_INVALID_HANDLE;
+ nwamerr(ret, "Unknown object type");
+ return;
}
if (ret != NWAM_SUCCESS)
nwamerr(ret, "Verify error on property '%s'", errprop);
@@ -4224,7 +4253,7 @@ one_command_at_a_time(int argc, char *argv[])
static int
cmd_file(char *file)
{
- FILE *infile;
+ FILE *infile = NULL;
int err;
struct stat statbuf;
boolean_t using_real_file = (strcmp(file, "-") != 0);
diff --git a/usr/src/man/man1m/acct.1m b/usr/src/man/man1m/acct.1m
index c46ac7d6d0..969996f9bf 100644
--- a/usr/src/man/man1m/acct.1m
+++ b/usr/src/man/man1m/acct.1m
@@ -3,12 +3,11 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH ACCT 1M "Feb 22, 1999"
+.TH ACCT 1M "August 29, 2021"
.SH NAME
acct, acctdisk, acctdusg, accton, acctwtmp, closewtmp, utmp2wtmp \- overview of
accounting and miscellaneous accounting commands
.SH SYNOPSIS
-.LP
.nf
\fB/usr/lib/acct/acctdisk\fR
.fi
@@ -39,8 +38,6 @@ accounting and miscellaneous accounting commands
.fi
.SH DESCRIPTION
-.sp
-.LP
Accounting software is structured as a set of tools (consisting of both C
programs and shell procedures) that can be used to build accounting systems.
\fBacctsh\fR(1M) describes the set of shell procedures built on top of the C
@@ -111,8 +108,6 @@ an entry in the file \fB/var/adm/wtmpx\fR, created by \fBrunacct\fR. Entries in
\fB/var/adm/wtmpx\fR enable subsequent invocations of \fBrunacct\fR to account
for connect times of users currently logged in.
.SH OPTIONS
-.sp
-.LP
The following options are supported:
.sp
.ne 2
@@ -136,8 +131,6 @@ password file is \fB/etc/passwd\fR.
.RE
.SH ENVIRONMENT VARIABLES
-.sp
-.LP
If any of the \fBLC_*\fR variables (\fBLC_TYPE\fR, \fBLC_MESSAGES\fR,
\fBLC_TIME\fR, \fBLC_COLLATE\fR, \fBLC_NUMERIC\fR, and \fBLC_MONETARY\fR) (see
\fBenviron\fR(5)) are not set in the environment, the operational behavior of
@@ -171,7 +164,6 @@ date and time handling follows the U.S. rules.
.RE
.SH FILES
-.sp
.ne 2
.na
\fB\fB/etc/passwd\fR\fR
@@ -204,12 +196,10 @@ Current process accounting file.
\fB\fB/var/adm/wtmpx\fR\fR
.ad
.RS 18n
-History of user access and administration information..
+History of user access and administration information.
.RE
.SH SEE ALSO
-.sp
-.LP
\fBacctcom\fR(1), \fBacctcms\fR(1M), \fBacctcon\fR(1M), \fBacctmerg\fR(1M),
\fBacctprc\fR(1M), \fBacctsh\fR(1M), \fBfwtmp\fR(1M), \fBrunacct\fR(1M),
\fBacct\fR(2), \fBacct.h\fR(3HEAD), \fBpasswd\fR(4), \fButmpx\fR(4),
diff --git a/usr/src/man/man1m/chat.1m b/usr/src/man/man1m/chat.1m
index 7b233ae62f..94745d550f 100644
--- a/usr/src/man/man1m/chat.1m
+++ b/usr/src/man/man1m/chat.1m
@@ -4,23 +4,20 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH CHAT 1M "April 9, 2016"
+.TH CHAT 1M "August 29, 2021"
.SH NAME
chat \- automated conversational exchange tool
.SH SYNOPSIS
-.LP
.nf
\fBchat\fR [\fIoptions\fR] \fIscript\fR
.fi
.SH DESCRIPTION
-.LP
The \fBchat\fR program implements a conversational text-based exchange between
the computer and any serial device, including (but not limited to) a modem, an
ISDN TA, and the remote peer itself, establishing a connection between the
Point-To-Point Protocol daemon (\fBpppd\fR) and the remote \fBpppd\fR process.
.SH OPTIONS
-.LP
The \fBchat\fR command supports the following options:
.sp
.ne 2
@@ -43,7 +40,7 @@ or horizontal tab characters to separate the strings.
Set the timeout for the expected string to be received. If the string is not
received within the time limit, the reply string is not sent. If specified,
a 'subexpect' (alternate reply) string can be sent. Otherwise, if no alternate
-reply strings remain, the \fBchat\fR script fails.. A failed script will cause
+reply strings remain, the \fBchat\fR script fails. A failed script will cause
the \fBchat\fR program to terminate with a non-zero error code.
.RE
@@ -159,7 +156,6 @@ is included as parameters to the \fBchat\fR program.
.SH EXTENDED DESCRIPTION
.SS "Chat Script"
-.LP
The \fBchat\fR script defines communications. A script consists of one or more
"expect-send" pairs of strings separated by spaces, with an optional
"subexpect-subsend" string pair, separated by a dash (as in the following
@@ -208,7 +204,7 @@ ogin: ppp ssword: hello2u2
.sp
.LP
-The example can be intrepreted as: expect ogin:, send ppp, expect ...ssword:,
+The example can be interpreted as: expect ogin:, send ppp, expect ...ssword:,
send hello2u2.
.sp
.LP
@@ -230,7 +226,6 @@ return sequence is sent and then the script looks for login: again. If line
noise obscures the first login prompt, send the empty line to generate a login
prompt again.
.SS "Comments"
-.LP
Comments can be embedded in the \fBchat\fR script. Comment lines are ignored by
the chat program. A comment starts with the hash ("#") character in column one.
If a \fB#\fR character is expected as the first character of the expect
@@ -245,7 +240,6 @@ with a \fB#\fR character, write something like this:
.in -2
.SS "Sending Data From A File"
-.LP
If the string to send begins with an at sign ("@"), the remainder of the string
is interpreted as the name of the file that contains the string. If the last
character of the data read is a newline, it is removed. The file can be a named
@@ -253,7 +247,6 @@ pipe (or fifo) instead of a regular file. This enables \fBchat\fR to
communicate with another program, for example, a program to prompt the user and
receive a password typed in.
.SS "Abort "
-.LP
Many modems report the status of a call as a string. These status strings are
often "CONNECTED" or "NO CARRIER" or "BUSY." If the modem fails to connect to
the remote, you can terminate the script. Abort strings may be specified in the
@@ -275,12 +268,10 @@ sends the string BUSY, causing the string to match the abort character
sequence. The script fails because it found a match to the abort string. If the
NO CARRIER string is received, it aborts for the same reason.
.SS "Clr_Abort "
-.LP
The CLR_ABORT sequence clears previously set ABORT strings. ABORT strings are
kept in an array of a pre-determined size; CLR_ABORT reclaims the space for
cleared entries, enabling new strings to use that space.
.SS "Say "
-.LP
The SAY string enables the script to send strings to a user at a terminal via
standard error. If \fBchat\fR is being run by \fBpppd\fR and \fBpppd\fR is
running as a daemon (detached from its controlling terminal), standard error is
@@ -326,7 +317,6 @@ Logged in OK ...
.in -2
.SS "Report"
-.LP
REPORT is similar to the ABORT string. With REPORT, however, strings and all
characters to the next control character (such as a carriage return), are
written to the report file.
@@ -359,12 +349,10 @@ remainder of the script is executed. In addition, the program writes the string
CONNECT to the report file (specified by \fB-r\fR) in addition to any
characters that follow.
.SS "Clr_Report"
-.LP
CLR_REPORT clears previously set REPORT strings. REPORT strings are kept in an
array of a pre-determined size; CLR_REPORT reclaims the space for cleared
entries so that new strings can use that space.
.SS "Echo"
-.LP
ECHO determines if modem output is echoed to \fBstderr\fR. This option may be
set with the \fB-e\fR option, but can also be controlled by the ECHO keyword.
The "expect-send" pair ECHO ON enables echoing, and ECHO OFF disables it. With
@@ -389,7 +377,6 @@ ogin: account
All output resulting from modem configuration and dialing is not visible, but
output is echoed beginning with the CONNECT (or BUSY) message.
.SS "Hangup"
-.LP
The HANGUP option determines if a modem hangup is considered as an error.
HANGUP is useful for dialing systems that hang up and call your system back.
HANGUP can be ON or OFF. When HANGUP is set to OFF and the modem hangs up (for
@@ -419,7 +406,6 @@ ABORT 'BUSY'
.in -2
.SS "Timeout"
-.LP
The initial timeout value is 45 seconds. Use the \fB-t\fR parameter to change
the initial timeout value.
.sp
@@ -448,21 +434,18 @@ prompt.
.LP
Once changed, the timeout value remains in effect until it is changed again.
.SS " EOT"
-.LP
The EOT special reply string instructs the \fBchat\fR program to send an EOT
character to the remote. This is equivalent to using ^D\ec as the reply string.
The EOT string normally indicates the end-of-file character sequence. A return
character is not sent following the EOT. The EOT sequence can embedded into the
send string using the sequence ^D.
.SS " BREAK"
-.LP
The BREAK special reply string sends a break condition. The break is a special
transmitter signal. Many UNIX systems handle break by cycling through available
bit rates, and sending break is often needed when the remote system does not
support autobaud. BREAK is equivalent to using \eK\ec as the reply string.
You embed the break sequence into the send string using the \eK sequence.
.SS "Escape Sequences"
-.LP
Expect and reply strings can contain escape sequences. Reply strings accept all
escape sequences, while expect strings accept most sequences. A list of escape
sequences is presented below. Sequences that are not accepted by expect strings
@@ -637,14 +620,12 @@ in expect.)
.RE
.SH ENVIRONMENT VARIABLES
-.LP
Environment variables are available within \fBchat\fR scripts if the \fB-E\fR
option is specified on the command line. The metacharacter \fB$\fR introduces
the name of the environment variable to substitute. If the substitution fails
because the requested environment variable is not set, nothing is replaced for
the variable.
.SH EXIT STATUS
-.LP
The \fBchat\fR program terminates with the following completion codes:
.sp
.ne 2
@@ -741,7 +722,6 @@ possible to decide if the string "BUSY" was received from the modem versus "NO
DIALTONE." While the first event may be retried, the second probably will not
succeed during a retry.
.SH ATTRIBUTES
-.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp
@@ -756,7 +736,6 @@ Interface Stability Evolving
.TE
.SH SEE ALSO
-.LP
\fBsleep\fR(1), \fBuucp\fR(1C), \fBpppd\fR(1M), \fBuucico\fR(1M),
\fBsyslog\fR(3C), \fBattributes\fR(5)
.sp
diff --git a/usr/src/man/man1m/format.1m b/usr/src/man/man1m/format.1m
index 292a9ccea5..03f2dd6983 100644
--- a/usr/src/man/man1m/format.1m
+++ b/usr/src/man/man1m/format.1m
@@ -4,11 +4,10 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH FORMAT 1M "Sep 25, 2008"
+.TH FORMAT 1M "August 29, 2021"
.SH NAME
format \- disk partitioning and maintenance utility
.SH SYNOPSIS
-.LP
.nf
\fBformat\fR [\fB-f\fR \fIcommand-file\fR] [\fB-l\fR \fIlog-file\fR] [\fB-x\fR \fIdata-file\fR]
[\fB-d\fR \fIdisk-name\fR] [\fB-t\fR \fIdisk-type\fR] [\fB-p\fR \fIpartition-name\fR]
@@ -16,8 +15,6 @@ format \- disk partitioning and maintenance utility
.fi
.SH DESCRIPTION
-.sp
-.LP
\fBformat\fR enables you to format, label, repair, and analyze disks on your
system. Unlike previous disk maintenance programs, \fBformat\fR runs under
SunOS. Because there are limitations to what can be done to the system disk
@@ -49,8 +46,6 @@ Removable media devices are listed only when users execute \fBformat\fR in
expert mode (option \fB-e\fR). This feature is provided for backward
compatibility. Use \fBrmformat\fR(1) for rewritable removable media devices.
.SH OPTIONS
-.sp
-.LP
The following options are supported:
.sp
.ne 2
@@ -163,8 +158,6 @@ Use the list of disks contained in \fIdata-file\fR.
.RE
.SH USAGE
-.sp
-.LP
When you invoke format with no options or with the \fB-e\fR, \fB-l\fR,
\fB-m\fR, \fB-M\fR, or \fB-s\fR options, the program displays a numbered list
of available disks and prompts you to specify a disk by list number. If the
@@ -209,7 +202,7 @@ Search for backup labels.
.RS 13n
Enable, disable, and query the state of the write cache and read cache. This
menu item only appears when \fBformat\fR is invoked with the \fB-e\fR option,
-and is only supported on \fBSCSI\fR devices..
+and is only supported on \fBSCSI\fR devices.
.RE
.sp
@@ -365,7 +358,6 @@ Label the disk with a new eight character volume name.
.RE
.SH ENVIRONMENT VARIABLES
-.sp
.ne 2
.na
\fB\fBFORMAT_PATH\fR\fR
@@ -377,7 +369,6 @@ definitions. If a directory is specified, \fBformat\fR searches for the file
.RE
.SH FILES
-.sp
.ne 2
.na
\fB\fB/etc/format.dat\fR\fR
@@ -387,20 +378,14 @@ default data file
.RE
.SH SEE ALSO
-.sp
-.LP
\fBfmthard\fR(1M), \fBprtvtoc\fR(1M), \fBrmformat\fR(1), \fBformat.dat\fR(4),
\fBattributes\fR(5), \fBsd\fR(7D)
.sp
.LP
\fI\fR
.SS "x86 Only"
-.sp
-.LP
\fBfdisk\fR(1M)
.SH WARNINGS
-.sp
-.LP
When the \fBformat\fR function is selected to format the Maxtor 207MB disk, the
following message displays:
.sp
@@ -434,8 +419,6 @@ than 2 TB. When \fBformat\fR is invoked with the \fB-e\fR option, on writing
the label, the label type can be chosen. Booting is not currently supported on
a disk with an EFI label.
.SH NOTES
-.sp
-.LP
\fBformat\fR provides a help facility you can use whenever format is expecting
input. You can request help about what information is expected by simply
entering a question mark (\fB?\fR) and \fBformat\fR prints a brief description
diff --git a/usr/src/man/man1m/fsdb_udfs.1m b/usr/src/man/man1m/fsdb_udfs.1m
index 0360ef0868..45be584aea 100644
--- a/usr/src/man/man1m/fsdb_udfs.1m
+++ b/usr/src/man/man1m/fsdb_udfs.1m
@@ -3,17 +3,15 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH FSDB_UDFS 1M "Nov 26, 2017"
+.TH FSDB_UDFS 1M "August 29, 2021"
.SH NAME
fsdb_udfs \- udfs file system debugger
.SH SYNOPSIS
-.LP
.nf
\fBfsdb \fR [\fB-F\fR] udfs [\fIgeneric_option\fR] [\fB-o \fR\fIspecific_option\fR] \fIspecial\fR
.fi
.SH DESCRIPTION
-.LP
The \fBfsdb_udfs\fR command is an interactive tool that can be used to patch up
a damaged \fBudfs\fR file system. \fBfsdb_udfs\fR has conversions to translate
block and i-numbers into their corresponding disk addresses. Mnemonic offsets
@@ -38,7 +36,6 @@ with the \fB-w\fR option.
Wherever possible, \fBadb\fR-like syntax has been adopted to promote the use of
\fBfsdb\fR through familiarity.
.SH OPTIONS
-.LP
The following options are supported:
.sp
.ne 2
@@ -87,7 +84,6 @@ Display usage.
.RE
.SH USAGE
-.LP
Numbers are considered hexadecimal by default. The user has control over how
data is to be displayed or accepted. The \fBbase\fR command displays or sets
the input and output base. Once set, all input defaults to this base and all
@@ -220,7 +216,6 @@ or
.LP
is again synonymous.
.SS "Expressions"
-.LP
The following symbols are recognized by \fBfsdb\fR:
.sp
.ne 2
@@ -390,7 +385,6 @@ of the address pointed to by dot by expression \fIe\fR.
.RE
.SS "Commands"
-.LP
A command must be prefixed by a colon (\fB:\fR). Only enough letters of the
command to uniquely distinguish it are needed. Multiple commands can be entered
on one line by separating them by a SPACE, TAB, or semicolon (\fB;\fR).
@@ -577,7 +571,6 @@ Escape to the shell.
.RE
.SS "Inode Commands"
-.LP
In addition to the above commands, several other commands deal with inode
fields and operate directly on the current inode (they still require the colon
(\fB:\fR). They can be used to more easily display or change the particular
@@ -699,7 +692,7 @@ allows you to change or display the directory name. For example,
gets the \fB7\fRth directory entry of the current inode and changes its name to
\fBfoo\fR. Directory names cannot be made larger than the field allows. If an
-attempt is made to make a directory name larger than the field allows,, the
+attempt is made to make a directory name larger than the field allows, the
string is truncated to fit and a warning message is displayed.
.RE
@@ -731,7 +724,6 @@ Unique \fBID\fR
.RE
.SS "Formatted Output"
-.LP
Formatted output comes in two styles and many format types. The two styles of
formatted output are: structured and unstructured. Structured output is used to
display inodes, directories, and so forth. Unstructured output displays raw
@@ -810,7 +802,6 @@ Display as hexadecimal shorts or longs.
.RE
.SH EXAMPLES
-.LP
\fBExample 1 \fRUsing fsdb as a calculator for complex arithmetic
.sp
.LP
@@ -826,7 +817,7 @@ of using \fBfsdb\fR as a calculator for complex arithmetic.
.sp
.LP
-\fBExample 2 \fRUsing fsdb to display an i-number in inode fomat
+\fBExample 2 \fRUsing fsdb to display an i-number in inode format
.sp
.LP
The following command displays the i-number \fB386\fR in inode format.\fB386\fR
@@ -912,7 +903,7 @@ associated with the current inode.
.sp
.LP
-\fBExample 8 \fRUsing fsdb to display the directory enteries for the root inode
+\fBExample 8 \fRUsing fsdb to display the directory entries for the root inode
.sp
.LP
The following command displays the first block's directory entries for the root
@@ -1012,5 +1003,4 @@ address \fB1c92434\fR.
.sp
.SH SEE ALSO
-.LP
\fBclri\fR(1M), \fBfsck_udfs\fR(1M), \fBdir\fR(4), \fBattributes\fR(5)
diff --git a/usr/src/man/man1m/reboot.1m b/usr/src/man/man1m/reboot.1m
index a4bdebd496..22ba85098e 100644
--- a/usr/src/man/man1m/reboot.1m
+++ b/usr/src/man/man1m/reboot.1m
@@ -4,11 +4,10 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License. You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing.
.\" See the License for the specific language governing permissions and limitations under the License. When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with
.\" the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH REBOOT 1M "Feb 21, 2016"
+.TH REBOOT 1M "August 29, 2021"
.SH NAME
reboot \- restart the operating system
.SH SYNOPSIS
-.LP
.nf
\fB/usr/sbin/reboot\fR [\fB-dlnq\fR] [\fIboot_arguments\fR]
.fi
@@ -19,7 +18,6 @@ reboot \- restart the operating system
.fi
.SH DESCRIPTION
-.LP
The \fBreboot\fR utility restarts the kernel. The kernel is loaded into memory
by the PROM monitor, which transfers control to the loaded kernel.
.sp
@@ -48,7 +46,6 @@ options are present.
.LP
Normally, the system reboots itself at power-up or after crashes.
.SH OPTIONS
-.LP
The following options are supported:
.sp
.ne 2
@@ -146,7 +143,6 @@ Quick. Reboot quickly without halting running zones first.
.RE
.SH OPERANDS
-.LP
The following operands are supported:
.sp
.ne 2
@@ -158,14 +154,13 @@ The following operands are supported:
An optional \fIboot_arguments\fR specifies arguments to the \fBuadmin\fR(2)
function that are passed to the boot program and kernel upon restart. The form
and list of arguments is described in the \fBboot\fR(1M) and \fBkernel\fR(1M)
-man pages.. If the arguments are specified, whitespace between them is replaced
+man pages. If the arguments are specified, whitespace between them is replaced
by single spaces unless the whitespace is quoted for the shell. If the
\fIboot_arguments\fR begin with a hyphen, they must be preceded by the \fB--\fR
delimiter (two hyphens) to denote the end of the \fBreboot\fR argument list.
.RE
.SH EXAMPLES
-.LP
\fBExample 1 \fRPassing the \fB-r\fR and \fB-v\fR Arguments to \fBboot\fR
.sp
.LP
@@ -353,13 +348,11 @@ login accounting file
.RE
.SH SEE ALSO
-.LP
\fBmdb\fR(1), \fBboot\fR(1M), \fBdumpadm\fR(1M), \fBfsck\fR(1M),
\fBhalt\fR(1M), \fBinit\fR(1M), \fBkernel\fR(1M), \fBshutdown\fR(1M),
\fBsvcadm\fR(1M), \fBsvccfg\fR(1M), \fBsync\fR(1M), \fBsyslogd\fR(1M),
\fBsync\fR(2), \fBuadmin\fR(2), \fBreboot\fR(3C), \fBattributes\fR(5)
.SH NOTES
-.LP
The \fBreboot\fR utility does not execute the scripts in
\fB/etc/rc\fInum\fR.d\fR or execute shutdown actions in \fBinittab\fR(4). To
ensure a complete shutdown of system services, use \fBshutdown\fR(1M) or
diff --git a/usr/src/man/man1m/route.1m b/usr/src/man/man1m/route.1m
index 089e768157..1e470b2fc0 100644
--- a/usr/src/man/man1m/route.1m
+++ b/usr/src/man/man1m/route.1m
@@ -4,7 +4,7 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH ROUTE 1M "Mar 26, 2018"
+.TH ROUTE 1M "August 29, 2021"
.SH NAME
route \- manually manipulate the routing tables
.SH SYNOPSIS
@@ -332,7 +332,7 @@ _
.sp
.LP
-Two modifiers avoid confusion between addresses and keywords (for example.,
+Two modifiers avoid confusion between addresses and keywords (for example,
\fBhost\fR used as a symbolic host name). You can distinguish a
\fIdestination\fR by preceding it with the \fB-dst\fR modifier. You can
distinguish a gateway address by using the \fB-gateway\fR modifier. If the
@@ -468,7 +468,7 @@ _
Pretend route was added by kernel or routing daemon
T}
\fB-reject\fR \fBRTF_REJECT\fR Emit an ICMP unreachable when matched
-\fB-blackhole\fR \fBRTF_BLACKHOLE\fR Silently discard packets duing updates
+\fB-blackhole\fR \fBRTF_BLACKHOLE\fR Silently discard packets during updates
\fB-proto1\fR \fBRTF_PROTO1\fR Set protocol specific routing flag #1
\fB-proto2\fR \fBRTF_PROTO2\fR Set protocol specific routing flag #2
\fB-private\fR \fBRTF_PRIVATE\fR Do not advertise this route
diff --git a/usr/src/man/man1m/update_drv.1m b/usr/src/man/man1m/update_drv.1m
index e4070bbde1..987a48de6e 100644
--- a/usr/src/man/man1m/update_drv.1m
+++ b/usr/src/man/man1m/update_drv.1m
@@ -3,11 +3,10 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH UPDATE_DRV 1M "Feb 10, 2009"
+.TH UPDATE_DRV 1M "August 29, 2021"
.SH NAME
update_drv \- modify device driver attributes
.SH SYNOPSIS
-.LP
.nf
\fBupdate_drv\fR [\fB-f\fR | \fB-v\fR] [\fB-n\fR] \fIdriver_module\fR
.fi
@@ -25,8 +24,6 @@ update_drv \- modify device driver attributes
.fi
.SH DESCRIPTION
-.sp
-.LP
The \fBupdate_drv\fR command informs the system about attribute changes to an
installed device driver. It can be used to re-read the \fBdriver.conf\fR(4)
file, or to add, modify, or delete a driver's minor node permissions or
@@ -44,8 +41,6 @@ Upon successfully updating the permissions, only the new driver minor nodes get
created with the modified set of file permissions. Existing driver minor nodes
do not get modified.
.SH OPTIONS
-.sp
-.LP
The following options are supported:
.sp
.ne 2
@@ -170,7 +165,7 @@ With the \fB-a\fR option, policy is a white-space separated list of complete
device policies. For the \fB-d\fR option, policy is a white space separated
list of minor device specifications. The minor device specifications are
matched exactly against the entries in \fB/etc/security/device_policy\fR, that
-is., no wildcard matching is performed.
+is, no wildcard matching is performed.
.RE
.sp
@@ -197,11 +192,10 @@ Verbose.
.RE
.SH EXAMPLES
-.LP
\fBExample 1 \fRAdding or Modifying an Existing Minor Permissions Entry
.sp
.LP
-The following command adds or modifies the exisitng minor permissions entry of
+The following command adds or modifies the existing minor permissions entry of
the \fBclone\fR driver:
.sp
@@ -287,8 +281,6 @@ example# update_drv -a -i '"/pci@8,600000/SUNW,qlc@4"' qlt
.sp
.SH EXIT STATUS
-.sp
-.LP
The following exit values are returned:
.sp
.ne 2
@@ -311,13 +303,9 @@ An error occurred.
.RE
.SH SEE ALSO
-.sp
-.LP
\fBadd_drv\fR(1M), \fBmodunload\fR(1M), \fBrem_drv\fR(1M),
\fBdriver.conf\fR(4), \fBattributes\fR(5), \fBprivileges\fR(5)
.SH NOTES
-.sp
-.LP
If \fB-a\fR or \fB-d\fR options are specified, \fBupdate_drv\fR does not reread
the \fBdriver.conf\fR file.
.sp
diff --git a/usr/src/man/man3c/getgrouplist.3c b/usr/src/man/man3c/getgrouplist.3c
index f1e10695e3..18906886c2 100644
--- a/usr/src/man/man3c/getgrouplist.3c
+++ b/usr/src/man/man3c/getgrouplist.3c
@@ -11,7 +11,7 @@
.\"
.\" Copyright 2020 Joyent, Inc.
.\"
-.Dd November 22, 2020
+.Dd August 28, 2021
.Dt GETGROUPLIST 3C
.Os
.Sh NAME
@@ -121,7 +121,7 @@ values on failure, however their implementations show that
may be set on failure.
Software using
.Fn getgrouplist
-should be aware of these differences when attemping to write portable
+should be aware of these differences when attempting to write portable
software.
.Sh EXAMPLES
.Sy Example 1
@@ -200,8 +200,8 @@ may be larger than the value returned by a successful call to
.Sy MT-Safe
.Sh SEE ALSO
.Xr groups 1 ,
+.Xr getgroups 2 ,
.Xr getuid 2 ,
.Xr getgrnam 3C ,
-.Xr getgroups 3C ,
.Xr initgroups 3C ,
.Xr limits.h 3HEAD
diff --git a/usr/src/man/man3curses/forms.3curses b/usr/src/man/man3curses/forms.3curses
index 3f244d3c79..7efb6fda0c 100644
--- a/usr/src/man/man3curses/forms.3curses
+++ b/usr/src/man/man3curses/forms.3curses
@@ -4,18 +4,15 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH FORMS 3CURSES "Dec 31, 1996"
+.TH FORMS 3CURSES "August 28, 2021"
.SH NAME
forms \- character based forms package
.SH SYNOPSIS
-.LP
.nf
\fB#include <form.h>\fR
.fi
.SH DESCRIPTION
-.sp
-.LP
The \fBform\fR library is built using the \fBcurses\fR library, and any program
using \fBforms\fR routines must call one of the \fBcurses\fR initialization
routines such as \fBinitscr\fR. A program using these routines must be compiled
@@ -30,8 +27,6 @@ fieldtype routines, which are used to create new field types for validating
fields; and form routines, which are used to create and customize forms, assign
pre/post processing functions, and display and interact with forms.
.SS "Current Default Values for Field Attributes"
-.sp
-.LP
The \fBforms\fR package establishes initial current default values for field
attributes. During field initialization, each field attribute is assigned the
current default value for that attribute. An application can change or retrieve
@@ -42,8 +37,6 @@ default field attribute value, subsequent fields created using
previously created fields are not changed if a current default attribute value
is changed.)
.SS "Routine Name Index"
-.sp
-.LP
The following table lists each \fBforms\fR routine and the name of the manual
page on which it is described.
.sp
@@ -61,7 +54,7 @@ page on which it is described.
\fBcurrent_field\fR
.ad
.RS 25n
-form_page(3X)
+form_page(3CURSES)
.RE
.sp
@@ -70,7 +63,7 @@ form_page(3X)
\fBdata_ahead\fR
.ad
.RS 25n
-form_data(3X)
+form_data(3CURSES)
.RE
.sp
@@ -79,7 +72,7 @@ form_data(3X)
\fBdata_behind\fR
.ad
.RS 25n
-form_data(3X)
+form_data(3CURSES)
.RE
.sp
@@ -88,7 +81,7 @@ form_data(3X)
\fBdup_field\fR
.ad
.RS 25n
-form_field_new(3X)
+form_field_new(3CURSES)
.RE
.sp
@@ -97,7 +90,7 @@ form_field_new(3X)
\fBdynamic_field_info\fR
.ad
.RS 25n
-form_field_info(3X)
+form_field_info(3CURSES)
.RE
.sp
@@ -106,7 +99,7 @@ form_field_info(3X)
\fBfield_arg\fR
.ad
.RS 25n
-form_field_validation(3X)
+form_field_validation(3CURSES)
.RE
.sp
@@ -115,7 +108,7 @@ form_field_validation(3X)
\fBfield_back\fR
.ad
.RS 25n
-form_field_attributes(3X)
+form_field_attributes(3CURSES)
.RE
.sp
@@ -124,7 +117,7 @@ form_field_attributes(3X)
\fBfield_buffer\fR
.ad
.RS 25n
-form_field_buffer(3X)
+form_field_buffer(3CURSES)
.RE
.sp
@@ -133,7 +126,7 @@ form_field_buffer(3X)
\fBfield_count\fR
.ad
.RS 25n
-form_field(3X)
+form_field(3CURSES)
.RE
.sp
@@ -142,7 +135,7 @@ form_field(3X)
\fBfield_fore\fR
.ad
.RS 25n
-form_field_attributes(3X)
+form_field_attributes(3CURSES)
.RE
.sp
@@ -151,7 +144,7 @@ form_field_attributes(3X)
\fBfield_index\fR
.ad
.RS 25n
-form_page(3X)
+form_page(3CURSES)
.RE
.sp
@@ -160,7 +153,7 @@ form_page(3X)
\fBfield_info\fR
.ad
.RS 25n
-form_field_info(3X)
+form_field_info(3CURSES)
.RE
.sp
@@ -169,7 +162,7 @@ form_field_info(3X)
\fBfield_init\fR
.ad
.RS 25n
-form_hook(3X)
+form_hook(3CURSES)
.RE
.sp
@@ -178,7 +171,7 @@ form_hook(3X)
\fBfield_just\fR
.ad
.RS 25n
-form_field_just(3X)
+form_field_just(3CURSES)
.RE
.sp
@@ -187,7 +180,7 @@ form_field_just(3X)
\fBfield_opts\fR
.ad
.RS 25n
-form_field_opts(3X)
+form_field_opts(3CURSES)
.RE
.sp
@@ -196,7 +189,7 @@ form_field_opts(3X)
\fBfield_opts_off\fR
.ad
.RS 25n
-form_field_opts(3X)
+form_field_opts(3CURSES)
.RE
.sp
@@ -205,7 +198,7 @@ form_field_opts(3X)
\fBfield_opts_on\fR
.ad
.RS 25n
-form_field_opts(3X)
+form_field_opts(3CURSES)
.RE
.sp
@@ -214,7 +207,7 @@ form_field_opts(3X)
\fBfield_pad\fR
.ad
.RS 25n
-form_field_attributes(3X)
+form_field_attributes(3CURSES)
.RE
.sp
@@ -223,7 +216,7 @@ form_field_attributes(3X)
\fBfield_status\fR
.ad
.RS 25n
-form_field_buffer(3X)
+form_field_buffer(3CURSES)
.RE
.sp
@@ -232,7 +225,7 @@ form_field_buffer(3X)
\fBfield_term\fR
.ad
.RS 25n
-form_hook(3X)
+form_hook(3CURSES)
.RE
.sp
@@ -241,7 +234,7 @@ form_hook(3X)
\fBfield_type\fR
.ad
.RS 25n
-form_field_validation(3X)
+form_field_validation(3CURSES)
.RE
.sp
@@ -250,7 +243,7 @@ form_field_validation(3X)
\fBfield_userptr\fR
.ad
.RS 25n
-form_field_userptr(3X)
+form_field_userptr(3CURSES)
.RE
.sp
@@ -259,7 +252,7 @@ form_field_userptr(3X)
\fBform_driver\fR
.ad
.RS 25n
-form_driver(3X)
+form_driver(3CURSES)
.RE
.sp
@@ -268,7 +261,7 @@ form_driver(3X)
\fBform_fields\fR
.ad
.RS 25n
-form_field(3X)
+form_field(3CURSES)
.RE
.sp
@@ -277,7 +270,7 @@ form_field(3X)
\fBform_init\fR
.ad
.RS 25n
-form_hook(3X)
+form_hook(3CURSES)
.RE
.sp
@@ -286,7 +279,7 @@ form_hook(3X)
\fBform_opts\fR
.ad
.RS 25n
-form_opts(3X)
+form_opts(3CURSES)
.RE
.sp
@@ -295,7 +288,7 @@ form_opts(3X)
\fBform_opts_off\fR
.ad
.RS 25n
-form_opts(3X)
+form_opts(3CURSES)
.RE
.sp
@@ -304,7 +297,7 @@ form_opts(3X)
\fBform_opts_on\fR
.ad
.RS 25n
-form_opts(3X)
+form_opts(3CURSES)
.RE
.sp
@@ -313,7 +306,7 @@ form_opts(3X)
\fBform_page\fR
.ad
.RS 25n
-form_page(3X)
+form_page(3CURSES)
.RE
.sp
@@ -322,7 +315,7 @@ form_page(3X)
\fBform_sub\fR
.ad
.RS 25n
-form_win(3X)
+form_win(3CURSES)
.RE
.sp
@@ -331,7 +324,7 @@ form_win(3X)
\fBform_term\fR
.ad
.RS 25n
-form_hook(3X)
+form_hook(3CURSES)
.RE
.sp
@@ -340,7 +333,7 @@ form_hook(3X)
\fBform_userptr\fR
.ad
.RS 25n
-form_userptr(3X)
+form_userptr(3CURSES)
.RE
.sp
@@ -349,7 +342,7 @@ form_userptr(3X)
\fBform_win\fR
.ad
.RS 25n
-form_win(3X)
+form_win(3CURSES)
.RE
.sp
@@ -358,7 +351,7 @@ form_win(3X)
\fBfree_field\fR
.ad
.RS 25n
-form_field_new(3X)
+form_field_new(3CURSES)
.RE
.sp
@@ -367,7 +360,7 @@ form_field_new(3X)
\fBfree_fieldtype\fR
.ad
.RS 25n
-form_fieldtype(3X)
+form_fieldtype(3CURSES)
.RE
.sp
@@ -376,7 +369,7 @@ form_fieldtype(3X)
\fBfree_form\fR
.ad
.RS 25n
-form_new(3X)
+form_new(3CURSES)
.RE
.sp
@@ -385,7 +378,7 @@ form_new(3X)
\fBlink_field\fR
.ad
.RS 25n
-form_field_new(3X)
+form_field_new(3CURSES)
.RE
.sp
@@ -394,7 +387,7 @@ form_field_new(3X)
\fBlink_fieldtype\fR
.ad
.RS 25n
-form_fieldtype(3X)
+form_fieldtype(3CURSES)
.RE
.sp
@@ -403,7 +396,7 @@ form_fieldtype(3X)
\fBmove_field\fR
.ad
.RS 25n
-form_field(3X)
+form_field(3CURSES)
.RE
.sp
@@ -412,7 +405,7 @@ form_field(3X)
\fBnew_field\fR
.ad
.RS 25n
-form_field_new(3X)
+form_field_new(3CURSES)
.RE
.sp
@@ -421,7 +414,7 @@ form_field_new(3X)
\fBnew_fieldtype\fR
.ad
.RS 25n
-form_fieldtype(3X)
+form_fieldtype(3CURSES)
.RE
.sp
@@ -430,7 +423,7 @@ form_fieldtype(3X)
\fBnew_form\fR
.ad
.RS 25n
-form_new(3X)
+form_new(3CURSES)
.RE
.sp
@@ -439,7 +432,7 @@ form_new(3X)
\fBnew_page\fR
.ad
.RS 25n
-form_new_page(3X)
+form_new_page(3CURSES)
.RE
.sp
@@ -448,7 +441,7 @@ form_new_page(3X)
\fBpos_form_cursor\fR
.ad
.RS 25n
-form_cursor(3X)
+form_cursor(3CURSES)
.RE
.sp
@@ -457,7 +450,7 @@ form_cursor(3X)
\fBpost_form\fR
.ad
.RS 25n
-form_post(3X)
+form_post(3CURSES)
.RE
.sp
@@ -466,7 +459,7 @@ form_post(3X)
\fBscale_form\fR
.ad
.RS 25n
-form_win(3X)
+form_win(3CURSES)
.RE
.sp
@@ -475,7 +468,7 @@ form_win(3X)
\fBset_current_field\fR
.ad
.RS 25n
-form_page(3X)
+form_page(3CURSES)
.RE
.sp
@@ -484,7 +477,7 @@ form_page(3X)
\fBset_field_back\fR
.ad
.RS 25n
-form_field_attributes(3X)
+form_field_attributes(3CURSES)
.RE
.sp
@@ -493,7 +486,7 @@ form_field_attributes(3X)
\fBset_field_buffer\fR
.ad
.RS 25n
-form_field_buffer(3X)
+form_field_buffer(3CURSES)
.RE
.sp
@@ -502,7 +495,7 @@ form_field_buffer(3X)
\fBset_field_fore\fR
.ad
.RS 25n
-form_field_attributes(3X)
+form_field_attributes(3CURSES)
.RE
.sp
@@ -511,7 +504,7 @@ form_field_attributes(3X)
\fBset_field_init\fR
.ad
.RS 25n
-form_hook(3X)
+form_hook(3CURSES)
.RE
.sp
@@ -520,7 +513,7 @@ form_hook(3X)
\fB set_field_just\fR
.ad
.RS 25n
-form_field_just(3X)
+form_field_just(3CURSES)
.RE
.sp
@@ -529,7 +522,7 @@ form_field_just(3X)
\fBset_field_opts\fR
.ad
.RS 25n
-form_field_opts(3X)
+form_field_opts(3CURSES)
.RE
.sp
@@ -538,7 +531,7 @@ form_field_opts(3X)
\fBset_field_pad\fR
.ad
.RS 25n
-form_field_attributes(3X)
+form_field_attributes(3CURSES)
.RE
.sp
@@ -547,7 +540,7 @@ form_field_attributes(3X)
\fBset_field_status\fR
.ad
.RS 25n
-form_field_buffer(3X)
+form_field_buffer(3CURSES)
.RE
.sp
@@ -556,7 +549,7 @@ form_field_buffer(3X)
\fBset_field_term\fR
.ad
.RS 25n
-form_hook(3X)
+form_hook(3CURSES)
.RE
.sp
@@ -565,7 +558,7 @@ form_hook(3X)
\fBset_field_type\fR
.ad
.RS 25n
-form_field_validation(3X)
+form_field_validation(3CURSES)
.RE
.sp
@@ -574,7 +567,7 @@ form_field_validation(3X)
\fBset_field_userptr\fR
.ad
.RS 25n
-form_field_userptr(3X)
+form_field_userptr(3CURSES)
.RE
.sp
@@ -583,7 +576,7 @@ form_field_userptr(3X)
\fBset_fieldtype_arg\fR
.ad
.RS 25n
-form_fieldtype(3X)
+form_fieldtype(3CURSES)
.RE
.sp
@@ -592,7 +585,7 @@ form_fieldtype(3X)
\fBset_fieldtype_choice\fR
.ad
.RS 25n
-form_fieldtype(3X)
+form_fieldtype(3CURSES)
.RE
.sp
@@ -601,7 +594,7 @@ form_fieldtype(3X)
\fBset_form_fields\fR
.ad
.RS 25n
-form_field(3X)
+form_field(3CURSES)
.RE
.sp
@@ -610,7 +603,7 @@ form_field(3X)
\fBset_form_init\fR
.ad
.RS 25n
-form_hook(3X)
+form_hook(3CURSES)
.RE
.sp
@@ -619,7 +612,7 @@ form_hook(3X)
\fBset_form_opts\fR
.ad
.RS 25n
-form_opts(3X)
+form_opts(3CURSES)
.RE
.sp
@@ -628,7 +621,7 @@ form_opts(3X)
\fBset_form_page\fR
.ad
.RS 25n
-form_page(3X)
+form_page(3CURSES)
.RE
.sp
@@ -637,7 +630,7 @@ form_page(3X)
\fBset_form_sub\fR
.ad
.RS 25n
-form_win(3X)
+form_win(3CURSES)
.RE
.sp
@@ -646,7 +639,7 @@ form_win(3X)
\fBset_form_term\fR
.ad
.RS 25n
-form_hook(3X)
+form_hook(3CURSES)
.RE
.sp
@@ -655,7 +648,7 @@ form_hook(3X)
\fBset_form_userptr\fR
.ad
.RS 25n
-form_userptr(3X)
+form_userptr(3CURSES)
.RE
.sp
@@ -664,7 +657,7 @@ form_userptr(3X)
\fBset_form_win\fR
.ad
.RS 25n
-form_win(3X)
+form_win(3CURSES)
.RE
.sp
@@ -673,7 +666,7 @@ form_win(3X)
\fBset_max_field\fR
.ad
.RS 25n
-form_field_buffer(3X)
+form_field_buffer(3CURSES)
.RE
.sp
@@ -682,7 +675,7 @@ form_field_buffer(3X)
\fBset_new_page\fR
.ad
.RS 25n
-form_new_page(3X)
+form_new_page(3CURSES)
.RE
.sp
@@ -691,12 +684,10 @@ form_new_page(3X)
\fBunpost_form\fR
.ad
.RS 25n
-form_post(3X)
+form_post(3CURSES)
.RE
.SH RETURN VALUES
-.sp
-.LP
Routines that return a pointer always return \fINULL\fR on error. Routines that
return an integer return one of the following:
.sp
@@ -817,8 +808,6 @@ An unknown request was passed to the form driver.
.RE
.SH ATTRIBUTES
-.sp
-.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp
@@ -833,11 +822,7 @@ MT-Level Unsafe
.TE
.SH SEE ALSO
-.sp
-.LP
\fBcurses\fR(3CURSES), \fBattributes\fR(5)
.SH NOTES
-.sp
-.LP
The header \fB<form.h>\fR automatically includes the headers \fB<eti.h>\fR and
\fB<curses.h>\fR\&.
diff --git a/usr/src/man/man3curses/menus.3curses b/usr/src/man/man3curses/menus.3curses
index 832563ed86..ee571f1ac0 100644
--- a/usr/src/man/man3curses/menus.3curses
+++ b/usr/src/man/man3curses/menus.3curses
@@ -4,18 +4,15 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH MENUS 3CURSES "Dec 31, 1996"
+.TH MENUS 3CURSES "August 28, 2021"
.SH NAME
menus \- character based menus package
.SH SYNOPSIS
-.LP
.nf
\fB#include <menu.h>\fR
.fi
.SH DESCRIPTION
-.sp
-.LP
The \fBmenu\fR library is built using the \fBcurses\fR library, and any program
using menus routines must call one of the \fBcurses\fR initialization routines,
such as \fBinitscr\fR. A program using these routines must be compiled with
@@ -28,8 +25,6 @@ package includes: item routines, which are used to create and customize menu
items; and menu routines, which are used to create and customize menus, assign
pre- and post-processing routines, and display and interact with menus.
.SS "Current Default Values for Item Attributes"
-.sp
-.LP
The menus package establishes initial current default values for item
attributes. During item initialization, each item attribute is assigned the
current default value for that attribute. An application can change or retrieve
@@ -39,8 +34,6 @@ default item attribute value, subsequent items created using \fBnew_item()\fR
will have the new default attribute value. The attributes of previously created
items are not changed if a current default attribute value is changed.
.SS "Routine Name Index"
-.sp
-.LP
The following table lists each menus routine and the name of the manual page on
which it is described.
.sp
@@ -50,71 +43,69 @@ which it is described.
c c
l l .
\fBMenus Routine Name\fR \fBManual Page Name\fR
-\fBcurrent_item\fR \fBmenu_item_current(3X)\fR
-\fBfree_item\fR \fBmenu_item_new(3X)\fR
-\fBfree_menu\fR \fBmenu_new(3X)\fR
-\fBitem_count\fR \fBmenu_items(3X)\fR
-\fBitem_description\fR \fBmenu_item_name(3X)\fR
-\fBitem_index\fR \fBmenu_item_current(3X)\fR
-\fBitem_init\fR \fBmenu_hook(3X)\fR
-\fBitem_name\fR \fBmenu_item_name(3X)\fR
-\fBitem_opts\fR \fBmenu_item_opts(3X)\fR
-\fBitem_opts_off\fR \fBmenu_item_opts(3X)\fR
-\fBitem_opts_on\fR \fBmenu_item_opts(3X)\fR
-\fBitem_term\fR \fBmenu_hook(3X)\fR
-\fBitem_userptr\fR \fBmenu_item_userptr(3X)\fR
-\fBitem_value\fR \fBmenu_item_value(3X)\fR
-\fBitem_visible\fR \fBmenu_item_visible(3X)\fR
-\fBmenu_back\fR \fBmenu_attributes(3X)\fR
-\fBmenu_driver\fR \fBmenu_driver(3X)\fR
-\fBmenu_fore\fR \fBmenu_attributes(3X)\fR
-\fBmenu_format\fR \fBmenu_format(3X)\fR
-\fBmenu_grey\fR \fBmenu_attributes(3X)\fR
-\fBmenu_init\fR \fBmenu_hook(3X)\fR
-\fBmenu_items\fR \fBmenu_items(3X)\fR
-\fBmenu_mark\fR \fBmenu_mark(3X)\fR
-\fBmenu_opts\fR \fBmenu_opts(3X)\fR
-\fBmenu_opts_off\fR \fBmenu_opts(3X)\fR
-\fBmenu_opts_on\fR \fBmenu_opts(3X)\fR
-\fBmenu_pad\fR \fBmenu_attributes(3X)\fR
-\fBmenu_pattern\fR \fBmenu_pattern(3X)\fR
-\fBmenu_sub\fR \fBmenu_win(3X)\fR
-\fBmenu_term\fR \fBmenu_hook(3X)\fR
-\fBmenu_userptr\fR \fBmenu_userptr(3X)\fR
-\fBmenu_win\fR \fBmenu_win(3X)\fR
-\fBnew_item\fR \fBmenu_item_new(3X)\fR
-\fBnew_menu\fR \fBmenu_new(3X)\fR
-\fBpos_menu_cursor\fR \fBmenu_cursor(3X)\fR
-\fBpost_menu\fR \fBmenu_post(3X)\fR
-\fBscale_menu\fR \fBmenu_win(3X)\fR
-\fBset_current_item\fR \fBmenu_item_current(3X)\fR
-\fBset_item_init\fR \fBmenu_hook(3X)\fR
-\fBset_item_opts\fR \fBmenu_item_opts(3X)\fR
-\fBset_item_term\fR \fBmenu_hook(3X)\fR
-\fBset_item_userptr\fR \fBmenu_item_userptr(3X)\fR
-\fBset_item_value\fR \fBmenu_item_value(3X)\fR
-\fBset_menu_back\fR \fBmenu_attributes(3X)\fR
-\fBset_menu_fore\fR \fBmenu_attributes(3X)\fR
-\fBset_menu_format\fR \fBmenu_format(3X)\fR
-\fBset_menu_grey\fR \fBmenu_attributes(3X)\fR
-\fBset_menu_init\fR \fBmenu_hook(3X)\fR
-\fBset_menu_items\fR \fBmenu_items(3X)\fR
-\fBset_menu_mark\fR \fBmenu_mark(3X)\fR
-\fBset_menu_opts\fR \fBmenu_opts(3X)\fR
-\fBset_menu_pad\fR \fBmenu_attributes(3X)\fR
-\fBset_menu_pattern\fR \fBmenu_pattern(3X)\fR
-\fBset_menu_sub\fR \fBmenu_win(3X)\fR
-\fBset_menu_term\fR \fBmenu_hook(3X)\fR
-\fBset_menu_userptr\fR \fBmenu_userptr(3X)\fR
-\fBset_menu_win\fR \fBmenu_win(3X)\fR
-\fBset_top_row\fR \fBmenu_item_current(3X)\fR
-\fBtop_row\fR \fBmenu_item_current(3X)\fR
-\fBunpost_menu\fR \fBmenu_post(3X)\fR
+\fBcurrent_item\fR \fBmenu_item_current(3CURSES)\fR
+\fBfree_item\fR \fBmenu_item_new(3CURSES)\fR
+\fBfree_menu\fR \fBmenu_new(3CURSES)\fR
+\fBitem_count\fR \fBmenu_items(3CURSES)\fR
+\fBitem_description\fR \fBmenu_item_name(3CURSES)\fR
+\fBitem_index\fR \fBmenu_item_current(3CURSES)\fR
+\fBitem_init\fR \fBmenu_hook(3CURSES)\fR
+\fBitem_name\fR \fBmenu_item_name(3CURSES)\fR
+\fBitem_opts\fR \fBmenu_item_opts(3CURSES)\fR
+\fBitem_opts_off\fR \fBmenu_item_opts(3CURSES)\fR
+\fBitem_opts_on\fR \fBmenu_item_opts(3CURSES)\fR
+\fBitem_term\fR \fBmenu_hook(3CURSES)\fR
+\fBitem_userptr\fR \fBmenu_item_userptr(3CURSES)\fR
+\fBitem_value\fR \fBmenu_item_value(3CURSES)\fR
+\fBitem_visible\fR \fBmenu_item_visible(3CURSES)\fR
+\fBmenu_back\fR \fBmenu_attributes(3CURSES)\fR
+\fBmenu_driver\fR \fBmenu_driver(3CURSES)\fR
+\fBmenu_fore\fR \fBmenu_attributes(3CURSES)\fR
+\fBmenu_format\fR \fBmenu_format(3CURSES)\fR
+\fBmenu_grey\fR \fBmenu_attributes(3CURSES)\fR
+\fBmenu_init\fR \fBmenu_hook(3CURSES)\fR
+\fBmenu_items\fR \fBmenu_items(3CURSES)\fR
+\fBmenu_mark\fR \fBmenu_mark(3CURSES)\fR
+\fBmenu_opts\fR \fBmenu_opts(3CURSES)\fR
+\fBmenu_opts_off\fR \fBmenu_opts(3CURSES)\fR
+\fBmenu_opts_on\fR \fBmenu_opts(3CURSES)\fR
+\fBmenu_pad\fR \fBmenu_attributes(3CURSES)\fR
+\fBmenu_pattern\fR \fBmenu_pattern(3CURSES)\fR
+\fBmenu_sub\fR \fBmenu_win(3CURSES)\fR
+\fBmenu_term\fR \fBmenu_hook(3CURSES)\fR
+\fBmenu_userptr\fR \fBmenu_userptr(3CURSES)\fR
+\fBmenu_win\fR \fBmenu_win(3CURSES)\fR
+\fBnew_item\fR \fBmenu_item_new(3CURSES)\fR
+\fBnew_menu\fR \fBmenu_new(3CURSES)\fR
+\fBpos_menu_cursor\fR \fBmenu_cursor(3CURSES)\fR
+\fBpost_menu\fR \fBmenu_post(3CURSES)\fR
+\fBscale_menu\fR \fBmenu_win(3CURSES)\fR
+\fBset_current_item\fR \fBmenu_item_current(3CURSES)\fR
+\fBset_item_init\fR \fBmenu_hook(3CURSES)\fR
+\fBset_item_opts\fR \fBmenu_item_opts(3CURSES)\fR
+\fBset_item_term\fR \fBmenu_hook(3CURSES)\fR
+\fBset_item_userptr\fR \fBmenu_item_userptr(3CURSES)\fR
+\fBset_item_value\fR \fBmenu_item_value(3CURSES)\fR
+\fBset_menu_back\fR \fBmenu_attributes(3CURSES)\fR
+\fBset_menu_fore\fR \fBmenu_attributes(3CURSES)\fR
+\fBset_menu_format\fR \fBmenu_format(3CURSES)\fR
+\fBset_menu_grey\fR \fBmenu_attributes(3CURSES)\fR
+\fBset_menu_init\fR \fBmenu_hook(3CURSES)\fR
+\fBset_menu_items\fR \fBmenu_items(3CURSES)\fR
+\fBset_menu_mark\fR \fBmenu_mark(3CURSES)\fR
+\fBset_menu_opts\fR \fBmenu_opts(3CURSES)\fR
+\fBset_menu_pad\fR \fBmenu_attributes(3CURSES)\fR
+\fBset_menu_pattern\fR \fBmenu_pattern(3CURSES)\fR
+\fBset_menu_sub\fR \fBmenu_win(3CURSES)\fR
+\fBset_menu_term\fR \fBmenu_hook(3CURSES)\fR
+\fBset_menu_userptr\fR \fBmenu_userptr(3CURSES)\fR
+\fBset_menu_win\fR \fBmenu_win(3CURSES)\fR
+\fBset_top_row\fR \fBmenu_item_current(3CURSES)\fR
+\fBtop_row\fR \fBmenu_item_current(3CURSES)\fR
+\fBunpost_menu\fR \fBmenu_post(3CURSES)\fR
.TE
.SH RETURN VALUES
-.sp
-.LP
Routines that return pointers always return \fINULL\fR on error. Routines that
return an integer return one of the following:
.sp
@@ -235,8 +226,6 @@ The menu driver could not process the request.
.RE
.SH ATTRIBUTES
-.sp
-.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp
@@ -251,11 +240,7 @@ MT-Level Unsafe
.TE
.SH SEE ALSO
-.sp
-.LP
\fBcurses\fR(3CURSES), \fBattributes\fR(5)
.SH NOTES
-.sp
-.LP
The header \fB<menu.h>\fR automatically includes the headers \fB<eti.h>\fR and
\fB<curses.h>\fR\&.
diff --git a/usr/src/man/man3curses/panels.3curses b/usr/src/man/man3curses/panels.3curses
index b2338e2097..0f2dbb6362 100644
--- a/usr/src/man/man3curses/panels.3curses
+++ b/usr/src/man/man3curses/panels.3curses
@@ -4,18 +4,15 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH PANELS 3CURSES "Dec 31, 1996"
+.TH PANELS 3CURSES "August 28, 2021"
.SH NAME
panels \- character based panels package
.SH SYNOPSIS
-.LP
.nf
\fB#include <panel.h>\fR
.fi
.SH DESCRIPTION
-.sp
-.LP
The \fBpanel\fR library is built using the \fBcurses\fR library, and any
program using \fBpanels\fR routines must call one of the \fBcurses\fR
initialization routines such as \fBinitscr\fR. A program using these routines
@@ -35,8 +32,6 @@ The \fBpanels\fR package allows the applications programmer to create panels,
fetch and set their associated windows, shuffle panels in the deck, and
manipulate panels in other ways.
.SS "Routine Name Index"
-.sp
-.LP
The following table lists each \fBpanels\fR routine and the name of the manual
page on which it is described.
.sp
@@ -64,14 +59,10 @@ update_panels \fBpanel_update\fR(3CURSES)
.TE
.SH RETURN VALUES
-.sp
-.LP
Each \fBpanels\fR routine that returns a pointer to an object returns
\fBNULL\fR if an error occurs. Each panel routine that returns an integer,
returns \fBOK\fR if it executes successfully and \fBERR\fR if it does not.
.SH ATTRIBUTES
-.sp
-.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp
@@ -86,12 +77,8 @@ MT-Level Unsafe
.TE
.SH SEE ALSO
-.sp
-.LP
-\fBcurses\fR(3CURSES), \fBattributes\fR(5) and 3X pages whose names begin
+\fBcurses\fR(3CURSES), \fBattributes\fR(5) and 3CURSES pages whose names begin
"panel_" for detailed routine descriptions.
.SH NOTES
-.sp
-.LP
The header \fB<panel.h>\fR automatically includes the header
\fB<curses.h>\fR\&.
diff --git a/usr/src/man/man3ldap/ldap_error.3ldap b/usr/src/man/man3ldap/ldap_error.3ldap
index 42720765e2..071291ec42 100644
--- a/usr/src/man/man3ldap/ldap_error.3ldap
+++ b/usr/src/man/man3ldap/ldap_error.3ldap
@@ -4,12 +4,11 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH LDAP_ERROR 3LDAP "Nov 11, 2008"
+.TH LDAP_ERROR 3LDAP "August 29, 2021"
.SH NAME
ldap_error, ldap_err2string, ldap_perror, ldap_result2error \- LDAP protocol
error handling functions
.SH SYNOPSIS
-.LP
.nf
cc[ \fIflag\fR... ] \fIfile\fR... -lldap[ \fIlibrary\fR... ]
#include <lber.h>
@@ -29,8 +28,6 @@ cc[ \fIflag\fR... ] \fIfile\fR... -lldap[ \fIlibrary\fR... ]
.fi
.SH DESCRIPTION
-.sp
-.LP
These functions interpret the error codes that are returned by the LDAP API
routines. The \fBldap_perror()\fR and \fBldap_result2error()\fR functions are
deprecated for all new development. Use \fBldap_err2string()\fR instead.
@@ -58,8 +55,6 @@ indicates that the \fIres\fR parameter should be freed by a call to
Similar to the way \fBperror\fR(3C) works, the \fBldap_perror()\fR function can
be called to print an indication of the error to standard error.
.SH ERRORS
-.sp
-.LP
The possible values for an LDAP error code are:
.sp
.ne 2
@@ -518,7 +513,7 @@ A memory allocation call failed in an LDAP library function, for example,
.ad
.sp .6
.RS 4n
-The LDAP client has either lost its connetion to an LDAP server or it cannot
+The LDAP client has either lost its connection to an LDAP server or it cannot
establish a connection.
.RE
@@ -529,7 +524,7 @@ establish a connection.
.ad
.sp .6
.RS 4n
-The requested functionality is not supported., for example, when an LDAPv2
+The requested functionality is not supported, for example, when an LDAPv2
client requests some LDAPv3 functionality.
.RE
@@ -586,8 +581,6 @@ servers that the client can hop through to retrieve data.
.RE
.SH ATTRIBUTES
-.sp
-.LP
See \fBattributes\fR(5) for a description of the following attributes:
.sp
@@ -602,8 +595,6 @@ Interface Stability Committed
.TE
.SH SEE ALSO
-.sp
-.LP
\fBfflush\fR(3C), \fBldap\fR(3LDAP), \fBldap_bind\fR(3LDAP),
\fBldap_result\fR(3LDAP), \fBldap_parse_extended_result\fR(3LDAP),
\fBldap_parse_result\fR(3LDAP), \fBldap_parse_sasl_bind_result\fR(3LDAP),
diff --git a/usr/src/man/man3rsm/rsm_memseg_import_set_mode.3rsm b/usr/src/man/man3rsm/rsm_memseg_import_set_mode.3rsm
index 02c4b249f1..8e58337942 100644
--- a/usr/src/man/man3rsm/rsm_memseg_import_set_mode.3rsm
+++ b/usr/src/man/man3rsm/rsm_memseg_import_set_mode.3rsm
@@ -3,12 +3,11 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH RSM_MEMSEG_IMPORT_SET_MODE 3RSM "Jun 8, 2001"
+.TH RSM_MEMSEG_IMPORT_SET_MODE 3RSM "August 29, 2021"
.SH NAME
rsm_memseg_import_set_mode, rsm_memseg_import_get_mode \- set or get mode for
barrier scoping
.SH SYNOPSIS
-.LP
.nf
cc [ \fIflag\fR... ] \fIfile\fR... -lrsm [ \fIlibrary\fR... ]
#include <rsmapi.h>
@@ -24,12 +23,10 @@ cc [ \fIflag\fR... ] \fIfile\fR... -lrsm [ \fIlibrary\fR... ]
.fi
.SH DESCRIPTION
-.sp
-.LP
The \fBrsm_memseg_import_set_mode()\fR function provides support for optional
explicit barrier scoping in the functions described on the
\fBrsm_memseg_import_get\fR(3RSM) and \fBrsm_memseg_import_put\fR(3RSM) manual
-pages.. The two valid barrier modes are \fBRSM_BARRIER_MODE_EXPLICIT\fR and
+pages. The two valid barrier modes are \fBRSM_BARRIER_MODE_EXPLICIT\fR and
\fBRSM_BARRIER_MODE_IMPLICIT\fR. By default, the barrier mode is set to
\fBRSM_BARRIER_MODE_IMPLICIT\fR. When the mode is
\fBRSM_BARRIER_MODE_IMPLICIT\fR, an implicit barrier open and barrier close is
@@ -41,13 +38,9 @@ before any barrier operations, either implicit or explicit, are used.
The \fBrsm_memseg_import_get_mode()\fR function obtains the current value of
the mode used for barrier scoping in put functions.
.SH RETURN VALUES
-.sp
-.LP
Upon successful completion, these functions return 0. Otherwise, an error value
is returned to indicate the error.
.SH ERRORS
-.sp
-.LP
The \fBrsm_memseg_import_set_mode()\fR and \fBrsm_memseg_import_get_mode()\fR
functions can return the following errors:
.sp
@@ -60,8 +53,6 @@ Invalid segment handle.
.RE
.SH ATTRIBUTES
-.sp
-.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp
@@ -78,7 +69,5 @@ MT-Level MT-Safe
.TE
.SH SEE ALSO
-.sp
-.LP
\fBrsm_memseg_import_get\fR(3RSM), \fBrsm_memseg_import_init_barrier\fR(3RSM),
\fBrsm_memseg_import_put\fR(3RSM), \fBattributes\fR(5)
diff --git a/usr/src/man/man3sysevent/sysevents.3sysevent b/usr/src/man/man3sysevent/sysevents.3sysevent
index 60e6d6c973..c609802f40 100644
--- a/usr/src/man/man3sysevent/sysevents.3sysevent
+++ b/usr/src/man/man3sysevent/sysevents.3sysevent
@@ -11,7 +11,7 @@
.\"
.\" Copyright 2019 Joyent, Inc.
.\"
-.Dd July 15, 2019
+.Dd August 28, 2021
.Dt SYSEVENTS 3SYSEVENT
.Os
.Sh NAME
@@ -77,7 +77,7 @@ Indicates the ID of the zone that the data link belongs to.
.El
.Sh INTERFACE STABILITY
While the library interface in
-.Xr libsysevent 3SYSEVENT
+.Xr libsysevent 3LIB
is committed, unless otherwise indicated the events, classes, their
payloads, are private and subject to change at any time.
.Sh SEE ALSO
diff --git a/usr/src/man/man3tnf/tnfctl_indirect_open.3tnf b/usr/src/man/man3tnf/tnfctl_indirect_open.3tnf
index c91d790af2..4457f8d54a 100644
--- a/usr/src/man/man3tnf/tnfctl_indirect_open.3tnf
+++ b/usr/src/man/man3tnf/tnfctl_indirect_open.3tnf
@@ -3,12 +3,11 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH TNFCTL_INDIRECT_OPEN 3TNF "Mar 1, 2004"
+.TH TNFCTL_INDIRECT_OPEN 3TNF "August 29, 2021"
.SH NAME
tnfctl_indirect_open, tnfctl_check_libs \- control probes of another process
where caller provides /proc functionality
.SH SYNOPSIS
-.LP
.nf
\fBcc\fR [ \fIflag\fR ... ] \fIfile\fR ... \fB-ltnfctl\fR [ \fIlibrary\fR ... ]
#include <tnf/tnfctl.h>
@@ -23,8 +22,6 @@ where caller provides /proc functionality
.fi
.SH DESCRIPTION
-.sp
-.LP
The interfaces \fBtnfctl_indirect_open()\fR and \fBtnfctl_check_libs()\fR are
used to control probes in another process where the \fBlibtnfctl\fR(3TNF)
client has already opened \fBproc\fR(4) on the target process. An example of
@@ -61,7 +58,7 @@ struct tnfctl_ind_config {
.LP
The first field \fIp_read\fR is the address of a function that can read
\fBsize\fR bytes at address \fIaddr\fR in the target image into the buffer
-\fIbuf\fR. The function should return \fB0\fR upon success.. The second field
+\fIbuf\fR. The function should return \fB0\fR upon success. The second field
\fIp_write\fR is the address of a function that can write \fBsize\fR bytes at
address \fIaddr\fR in the target image from the buffer \fIbuf\fR. The function
should return \fB0\fR upon success. The third field \fIp_getpid\fR is the
@@ -92,7 +89,7 @@ typedef struct tnfctl_ind_obj_info {
int objfd; /* -1 indicates fd not available */
paddr_t text_base; /* virtual addr of text segment */
paddr_t data_base; /* virtual addr of data segment */
- const char *objname; /* null-term. pathname to loadobj */
+ const char *objname; /* null-term. pathname to loadobj */
} tnfctl_ind_obj_info_t;
.fi
.in -2
@@ -114,13 +111,9 @@ indirect mode, call \fBtnfctl_check_libs()\fR when such events occur to make
harmless. It is also harmless to call \fBtnfctl_check_libs()\fR when no such
events have occurred.
.SH RETURN VALUES
-.sp
-.LP
\fBtnfctl_indirect_open()\fR and \fBtnfctl_check_libs()\fR return
\fBTNFCTL_ERR_NONE\fR upon success.
.SH ERRORS
-.sp
-.LP
The following error codes apply to \fBtnfctl_indirect_open()\fR:
.sp
.ne 2
@@ -180,8 +173,6 @@ An internal error occurred.
.RE
.SH ATTRIBUTES
-.sp
-.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp
@@ -196,8 +187,6 @@ MT Level MT-Safe
.TE
.SH SEE ALSO
-.sp
-.LP
\fBprex\fR(1), \fBTNF_PROBE\fR(3TNF), \fBdlclose\fR(3C), \fBdlopen\fR(3C),
\fBlibtnfctl\fR(3TNF), \fBtnfctl_probe_enable\fR(3TNF),
\fBtnfctl_probe_trace\fR(3TNF), \fBtracing\fR(3TNF), \fBproc\fR(4),
@@ -206,8 +195,6 @@ MT Level MT-Safe
.LP
\fILinker and Libraries Guide\fR
.SH NOTES
-.sp
-.LP
\fBtnfctl_indirect_open()\fR should only be called after the dynamic linker has
mapped in all the libraries (rtld sync point) and called only after the process
is stopped. Indirect process probe control assumes the target process is
diff --git a/usr/src/man/man7d/vioblk.7d b/usr/src/man/man7d/vioblk.7d
index 29bf194585..26c45507bb 100644
--- a/usr/src/man/man7d/vioblk.7d
+++ b/usr/src/man/man7d/vioblk.7d
@@ -11,7 +11,7 @@
.\"
.\" Copyright 2020 Oxide Computer Company
.\"
-.Dd October 3, 2020
+.Dd August 28, 2021
.Dt VIOBLK 7D
.Os
.Sh NAME
@@ -64,7 +64,7 @@ for discovering devices,
for manipulating partition tables,
.Xr iostat 1M
for seeing device I/O statistics, and a subset of the
-.Xr dkio 7IO
+.Xr dkio 7I
ioctl requests to retrieve information about the device.
.Sh ARCHITECTURE
The
diff --git a/usr/src/man/man7d/wscons.7d b/usr/src/man/man7d/wscons.7d
index a39c3e9825..cbafe66ddd 100644
--- a/usr/src/man/man7d/wscons.7d
+++ b/usr/src/man/man7d/wscons.7d
@@ -1,14 +1,13 @@
'\" te
.\" Copyright (c) 2006 Sun Microsystems, Inc. All Rights Reserved.
-.\" Copyright 2019 Peter Tribble.
+.\" Copyright 2021 Peter Tribble.
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH WSCONS 7D "Apr 3, 2019"
+.TH WSCONS 7D "August 29, 2021"
.SH NAME
wscons \- workstation console
.SH SYNOPSIS
-.LP
.nf
\fB#include <sys/strredir.h>\fR
.fi
@@ -24,14 +23,12 @@ wscons \- workstation console
.fi
.SH DESCRIPTION
-.LP
The \fBwscons\fR workstation console consists of a workstation keyboard and
frame buffer that act together to emulate an \fBASCII\fR terminal. It includes
a redirection facility that allows I/O issued to the workstation console to be
diverted to a STREAMS device, enabling window systems to redirect output that
would otherwise appear directly on the frame buffer in corrupted form.
.SS "Redirection"
-.LP
The \fBwscons\fR redirection facility maintains a list of devices that are
designated as redirection targets through the \fBSRIOCSREDIR\fR ioctl described
below. Only the current entry is active; when the active entry is closed, the
@@ -64,7 +61,6 @@ device denoted by \fIfd\fR, and 0 if it is not.
.RE
.SS "ANSI Standard Terminal Emulation"
-.LP
The Solaris kernel terminal emulator provides ANSI X3.64 emulation both on
SPARC and x86 systems.
.sp
@@ -109,7 +105,6 @@ right-bottom edge, the line-feed function is performed (see \fBCTRL-J\fR
below). The line-feed function scrolls the screen up by one or more lines
before moving the cursor to the first character position on the next line.
.SS "Control Sequence Syntax"
-.LP
The \fBwscons\fR console defines a number of control sequences that may occur
during input. When a control sequence is written to the console, it affects
one of the control functions described below. Control sequences are not
@@ -122,7 +117,7 @@ A number of control sequences (or control character functions) are of the form:
\fBCTRL-\fR\fIx\fR
.sp
.LP
- where \fIx\fR represents a singe character., such as \fBCNTRL-J\fR for a line
+where \fIx\fR represents a single character, such as \fBCNTRL-J\fR for a line
feed.
.sp
.LP
@@ -243,7 +238,6 @@ parameter value of 1. Note that \fBESC[;5M\fR (interpreted as \fB`ESC[5M\fR')
is \fInot\fR equivalent to \fBESC[5;M\fR (interpreted as `\fBESC[5;1M\fR')
which is ultimately interpreted as `\fBESC[1M\fR').
.SS "ANSI Control Functions"
-.LP
The following paragraphs specify the \fBANSI\fR control functions implemented
by the console. Each description provides:
.RS +4
@@ -284,7 +278,6 @@ Initial setting of the mode for functions that set a mode. To restore the
initial settings, use the \fBSUNRESET\fR escape sequence.
.RE
.SS "Control Character Functions"
-.LP
The \fBwscons \fRcontrol character functions are:
.sp
.ne 2
@@ -444,7 +437,6 @@ The cursor moves to the leftmost character position on the current line.
.RE
.SS "Escape Sequence Functions"
-.LP
The \fBwscons \fRescape sequence functions are:
.sp
.ne 2
@@ -960,7 +952,6 @@ Takes no parameters. Resets all modes to default, restores current font from
.RE
.SH RETURN VALUES
-.LP
When there are no errors, the redirection ioctls have return values as
described above. Otherwise, they return \fB\(mi1\fR and set \fBerrno\fR to
indicate the error. If the target stream is in an error state, \fBerrno \fRis
@@ -1025,7 +1016,6 @@ Access system console
.RE
.SH ATTRIBUTES
-.LP
See \fBattributes\fR(5) for descriptions of the following attributes:
.sp
@@ -1040,11 +1030,9 @@ Interface Stability Stable
.TE
.SH SEE ALSO
-.LP
\fBeeprom\fR(1M), \fBioctl\fR(2), \fBpoll\fR(2), \fBread\fR(2),
\fBwrite\fR(2), \fBconsole\fR(7D), \fBvisual_io\fR(7I)
.SH WARNINGS
-.LP
The redirection ioctls block while there is I/O outstanding on the device
instance being redirected. If you try to redirect the workstation console while
there is a outstanding read, the workstation console will hang until the read
diff --git a/usr/src/man/man7i/mtio.7i b/usr/src/man/man7i/mtio.7i
index 4663f9c0cd..bea7b77ce6 100644
--- a/usr/src/man/man7i/mtio.7i
+++ b/usr/src/man/man7i/mtio.7i
@@ -14,7 +14,7 @@
.\" If applicable, add the following below this CDDL HEADER, with the
.\" fields enclosed by brackets "[]" replaced with your own identifying
.\" information: Portions Copyright [yyyy] [name of copyright owner]
-.Dd August 31, 2018
+.Dd August 28, 2021
.Dt MTIO 7I
.Os
.Sh NAME
@@ -166,7 +166,7 @@ The
.Sx Read Operation
and
.Sx Write Operation
-subsections contain more pertinent information reguarding persistent error handling.
+subsections contain more pertinent information regarding persistent error handling.
.Ss "Read Operation"
The
.Xr read 2
@@ -543,7 +543,7 @@ struct mtdrivetype {
*/
typedef enum {
ST_NO_EOF,
- ST_EOF_PENDING, /* filemrk pending */
+ ST_EOF_PENDING, /* filemark pending */
ST_EOF, /* at filemark */
ST_EOT_PENDING, /* logical eot pend. */
ST_EOT, /* at logical eot */
@@ -841,7 +841,7 @@ target driver may continue to return a
.Dq drive needs cleaning
status unless an
.Dv MTIOCGE
-.Xr ioct 2
+.Xr ioctl 2
call is made while the cleaning media is in the drive.
.Pp
The
@@ -1082,11 +1082,11 @@ past double EOF marks which otherwise indicate End-Of-recorded-media (EOM) in
the case of 1/2\(dq reel tape drives.
As an argument, it takes a pointer to an integer.
If 0 (zero) is the specified integer, then double EOF marks indicate
-End-Of-recodred-media (EOD).
+End-Of-recorded-media (EOM).
If 1 is the specified integer, the double EOF marks no longer indicate EOM,
thus allowing applications to read past two EOF marks.
In this case it is the responsibility of the application to detect
-end-of-recorded-media (EOM).
+End-Of-recorded-media (EOM).
The specified tape behavior will be in effect until the device is closed.
.Pp
For example:
diff --git a/usr/src/man/man9f/ddi_io_rep_get8.9f b/usr/src/man/man9f/ddi_io_rep_get8.9f
index f626ee6e69..5c3bceaa01 100644
--- a/usr/src/man/man9f/ddi_io_rep_get8.9f
+++ b/usr/src/man/man9f/ddi_io_rep_get8.9f
@@ -3,7 +3,7 @@
.\" The contents of this file are subject to the terms of the Common Development and Distribution License (the "License"). You may not use this file except in compliance with the License.
.\" You can obtain a copy of the license at usr/src/OPENSOLARIS.LICENSE or http://www.opensolaris.org/os/licensing. See the License for the specific language governing permissions and limitations under the License.
.\" When distributing Covered Code, include this CDDL HEADER in each file and include the License file at usr/src/OPENSOLARIS.LICENSE. If applicable, add the following below this CDDL HEADER, with the fields enclosed by brackets "[]" replaced with your own identifying information: Portions Copyright [yyyy] [name of copyright owner]
-.TH DDI_IO_REP_GET8 9F "Nov 1, 2005"
+.TH DDI_IO_REP_GET8 9F "August 29, 2021"
.SH NAME
ddi_io_rep_get8, ddi_io_rep_get16, ddi_io_rep_get32
\- read multiple data from the mapped device
@@ -22,13 +22,13 @@ register in I/O space
.LP
.nf
\fBvoid\fR \fBddi_io_rep_get16\fR(\fBddi_acc_handle_t\fR \fIhandle\fR, \fBuint16_t *\fR\fIhost_addr\fR,
- \fBuint16_t *\fR\fIdev_addr\fR,, \fBsize_t\fR \fIrepcount\fR);
+ \fBuint16_t *\fR\fIdev_addr\fR, \fBsize_t\fR \fIrepcount\fR);
.fi
.LP
.nf
\fBvoid\fR \fBddi_io_rep_get32\fR(\fBddi_acc_handle_t\fR \fIhandle\fR, \fBuint32_t *\fR\fIhost_addr\fR,
- \fBuint32_t *\fR\fIdev_addr\fR,, \fBsize_t\fR \fIrepcount\fR);
+ \fBuint32_t *\fR\fIdev_addr\fR, \fBsize_t\fR \fIrepcount\fR);
.fi
.SH INTERFACE LEVEL
diff --git a/usr/src/uts/i86pc/io/viona/viona_rx.c b/usr/src/uts/i86pc/io/viona/viona_rx.c
index e76d2ead75..dc3feb10fe 100644
--- a/usr/src/uts/i86pc/io/viona/viona_rx.c
+++ b/usr/src/uts/i86pc/io/viona/viona_rx.c
@@ -334,14 +334,17 @@ viona_recv_merged(viona_vring_t *ring, const mblk_t *mp, size_t msz)
/*
* If there is any space remaining in the first buffer after writing
* the header, fill it with frame data.
*/
if (iov[0].iov_len > hdr_sz) {
buf = iov[0].iov_base + hdr_sz;
len = iov[0].iov_len - hdr_sz;
- chunk += viona_copy_mblk(mp, copied, buf, len, &end);
- copied += chunk;
+ size_t copy_len;
+ copy_len = viona_copy_mblk(mp, copied, buf, len, &end);
+ chunk += copy_len;
+ copied += copy_len;
}
i = 1;
@@ -350,8 +353,10 @@ viona_recv_merged(viona_vring_t *ring, const mblk_t *mp, size_t msz)
buf = iov[i].iov_base;
len = iov[i].iov_len;
- chunk += viona_copy_mblk(mp, copied, buf, len, &end);
- copied += chunk;
+ size_t copy_len;
+ copy_len = viona_copy_mblk(mp, copied, buf, len, &end);
+ chunk += copy_len;
+ copied += copy_len;
i++;
}
@@ -334,14 +334,17 @@ viona_recv_merged(viona_vring_t *ring, const mblk_t *mp, size_t msz)
/*
* If there is any space remaining in the first buffer after writing
- * the header, fill it with frame data.
+ * the header, fill it with frame data. The size of the header itself
+ * is accounted for later.
*/
if (iov[0].iov_len > hdr_sz) {